package com.ruoyi.mall.service;

import java.util.List;
import java.util.Map;

import com.ruoyi.mall.domain.MallGoodsGoods;
import com.ruoyi.mall.domain.MallImg;

/**
 * 图片Service接口
 *
 * @author chang
 * @date 2021-11-25
 */
public interface IMallImgService
{
    /**
     * 查询图片
     *
     * @param id 图片主键
     * @return 图片
     */
    public MallImg selectMallImgById(Long id);

    /**
     * 查询图片列表
     *
     * @param mallImg 图片
     * @return 图片集合
     */
    public List<MallImg> selectMallImgList(MallImg mallImg);

    /**
     * 新增图片
     *
     * @param mallImg 图片
     * @return 结果
     */
    public int insertMallImg(MallImg mallImg);

    /**
     * 修改图片
     *
     * @param mallImg 图片
     * @return 结果
     */
    public int updateMallImg(MallImg mallImg);

    /**
     * 批量删除图片
     *
     * @param ids 需要删除的图片主键集合
     * @return 结果
     */
    public int deleteMallImgByIds(Long[] ids);

    /**
     * 删除图片信息
     *
     * @param id 图片主键
     * @return 结果
     */
    public int deleteMallImgById(Long id);

    public List<String> selectMallImgUrlVoList(MallImg mallImg);

    public void deleteMallImgByImgVO(MallImg deleteImgVO);

    /**
     * 批量删除图片信息
     *
     * @param list 商品列表
     * @return 结果
     */
    public int batchDeleteMallImgByResId(List<MallGoodsGoods> list);

    /**
     * 批量新增图片信息
     *
     * @param list 图片列表
     * @return 结果
     */
    public int batchInsertMallImgByList(List<MallImg> list);
}
