package com.ruoyi.mall.controller;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.mall.domain.MallImg;
import com.ruoyi.mall.service.IMallImgService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 图片Controller
 * 
 * @author chang
 * @date 2021-11-25
 */
@RestController
@RequestMapping("/mall/mallImg")
public class MallImgController extends BaseController
{
    @Autowired
    private IMallImgService mallImgService;

    /**
     * 查询图片列表
     */
    @PreAuthorize("@ss.hasPermi('mall:mallImg:list')")
    @GetMapping("/list")
    public TableDataInfo list(MallImg mallImg)
    {
        startPage();
        List<MallImg> list = mallImgService.selectMallImgList(mallImg);
        return getDataTable(list);
    }

    /**
     * 导出图片列表
     */
    @PreAuthorize("@ss.hasPermi('mall:mallImg:export')")
    @Log(title = "图片", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(MallImg mallImg)
    {
        List<MallImg> list = mallImgService.selectMallImgList(mallImg);
        ExcelUtil<MallImg> util = new ExcelUtil<MallImg>(MallImg.class);
        return util.exportExcel(list, "图片数据");
    }

    /**
     * 获取图片详细信息
     */
    @PreAuthorize("@ss.hasPermi('mall:mallImg:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(mallImgService.selectMallImgById(id));
    }

    /**
     * 新增图片
     */
    @PreAuthorize("@ss.hasPermi('mall:mallImg:add')")
    @Log(title = "图片", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody MallImg mallImg)
    {
        return toAjax(mallImgService.insertMallImg(mallImg));
    }

    /**
     * 修改图片
     */
    @PreAuthorize("@ss.hasPermi('mall:mallImg:edit')")
    @Log(title = "图片", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody MallImg mallImg)
    {
        return toAjax(mallImgService.updateMallImg(mallImg));
    }

    /**
     * 删除图片
     */
    @PreAuthorize("@ss.hasPermi('mall:mallImg:remove')")
    @Log(title = "图片", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(mallImgService.deleteMallImgByIds(ids));
    }
}
